/*
    lm78.h - Header file for the Linux sensor programs
    Copyright (c) 1997, 1998  Alexander Larsson <alla@lysator.liu.se>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Heavily patched by Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock
   (phil@Stimpy.netroedge.com). */

#ifndef LM78_H
#define LM78_H

#define LM78_BASE 0x290
#define LM78_EXTENT 0x7
#define LM78_ADDRESS_REG (LM78_BASE + 0x5)
#define LM78_DATA_REG (LM78_BASE + 0x6)

#define LM78_BUSY ( inb_p( LM78_ADDRESS_REG ) & (1<<7) )

#define LM78_DUMMY 0x20

#define LM78_READ(addr) ({ \
outb_p((addr),LM78_ADDRESS_REG); \
inb_p(LM78_DATA_REG); \
})

#define LM78_WRITE(addr,x)  \
outb_p( (addr), LM78_ADDRESS_REG ); \
outb_p( (x), LM78_DATA_REG )

#define LM78_IN0 0x20     
#define LM78_IN1 0x21     
#define LM78_IN2 0x22     
#define LM78_IN3 0x23     
#define LM78_IN4 0x24     
#define LM78_MINUS_IN5 0x25
#define LM78_MINUS_IN6 0x26     
#define LM78_TEMPERATURE 0x27
#define LM78_FAN1 0x28
#define LM78_FAN2 0x29
#define LM78_FAN3 0x2A

#define LM78_CONFIG 0x40
#define LM78_FANDIV 0x47

/* Calculate rpms from tacho-count */
#define LM78_RPM(count,div) (1350000/(count*div))

#define LM78_ASUS_TX97 1

#ifdef LM78_ASUS_TX97
# define LM78_VCORE LM78_IN0
# define LM78_3_3V LM78_IN2
# define LM78_5V LM78_IN3   
# define LM78_12V LM78_IN4
# define LM78_M12V LM78_MINUS_IN5
# define LM78_M5V LM78_MINUS_IN6

# define LM78_VCORE_A 200  
# define LM78_VCORE_B 125  
# define LM78_3_3V_A 200  
# define LM78_3_3V_B 125  
# define LM78_5V_A 334
# define LM78_5V_B 125
# define LM78_M5V_A 300
# define LM78_M5V_B 125
# define LM78_12V_A 758
# define LM78_12V_B 125
# define LM78_M12V_A 700
# define LM78_M12V_B 125
#endif

  
#endif /* LM78 */


